@@ -19,9 +19,13 @@
 """
 Example Airflow DAG that interacts with Google Data Catalog service
 """
+import os
+from datetime import datetime
+
 from google.cloud.datacatalog_v1beta1 import FieldType, TagField, TagTemplateField
 
 from airflow import models
+from airflow.models.baseoperator import chain
 from airflow.operators.bash import BashOperator
 from airflow.providers.google.cloud.operators.datacatalog import (
     CloudDataCatalogCreateEntryGroupOperator,
@@ -46,10 +50,9 @@ from airflow.providers.google.cloud.operators.datacatalog import (
     CloudDataCatalogUpdateTagTemplateFieldOperator,
     CloudDataCatalogUpdateTagTemplateOperator,
 )
-from airflow.utils.dates import days_ago
-from airflow.utils.helpers import chain
 
-PROJECT_ID = "polidea-airflow"
+PROJECT_ID = os.getenv("GCP_PROJECT_ID")
+BUCKET_ID = os.getenv("GCP_TEST_DATA_BUCKET", "INVALID BUCKET NAME")
 LOCATION = "us-central1"
 ENTRY_GROUP_ID = "important_data_jan_2019"
 ENTRY_ID = "python_files"
@@ -58,7 +61,12 @@ FIELD_NAME_1 = "first"
 FIELD_NAME_2 = "second"
 FIELD_NAME_3 = "first-rename"
 
-with models.DAG("example_gcp_datacatalog", start_date=days_ago(1), schedule_interval=None) as dag:
+with models.DAG(
+    "example_gcp_datacatalog",
+    schedule_interval='@once',
+    start_date=datetime(2021, 1, 1),
+    catchup=False,
+) as dag:
     # Create
     # [START howto_operator_gcp_datacatalog_create_entry_group]
     create_entry_group = CloudDataCatalogCreateEntryGroupOperator(
@@ -92,7 +100,7 @@ with models.DAG("example_gcp_datacatalog", start_date=days_ago(1), schedule_inte
         entry={
             "display_name": "Wizard",
             "type_": "FILESET",
-            "gcs_fileset_spec": {"file_patterns": ["gs://INVALID BUCKET NAME/**"]},
+            "gcs_fileset_spec": {"file_patterns": [f"gs://{BUCKET_ID}/**"]},
         },
     )
     # [END howto_operator_gcp_datacatalog_create_entry_gcs]
