@@ -23,6 +23,7 @@ This example requires that your project contains Datastore instance.
 """
 
 import os
+from datetime import datetime
 from typing import Any, Dict
 
 from airflow import models
@@ -35,15 +36,17 @@ from airflow.providers.google.cloud.operators.datastore import (
     CloudDatastoreRollbackOperator,
     CloudDatastoreRunQueryOperator,
 )
-from airflow.utils import dates
+
+START_DATE = datetime(2021, 1, 1)
 
 GCP_PROJECT_ID = os.environ.get("GCP_PROJECT_ID", "example-project")
 BUCKET = os.environ.get("GCP_DATASTORE_BUCKET", "datastore-system-test")
 
 with models.DAG(
     "example_gcp_datastore",
-    schedule_interval=None,  # Override to match your needs
-    start_date=dates.days_ago(1),
+    schedule_interval='@once',  # Override to match your needs
+    start_date=START_DATE,
+    catchup=False,
     tags=["example"],
 ) as dag:
     # [START how_to_export_task]
@@ -82,8 +85,9 @@ TRANSACTION_OPTIONS: Dict[str, Any] = {"readWrite": {}}
 
 with models.DAG(
     "example_gcp_datastore_operations",
-    start_date=dates.days_ago(1),
-    schedule_interval=None,  # Override to match your needs
+    schedule_interval='@once',  # Override to match your needs
+    start_date=START_DATE,
+    catchup=False,
     tags=["example"],
 ) as dag2:
     # [START how_to_allocate_ids]
@@ -131,7 +135,7 @@ with models.DAG(
 
     # [START how_to_query_def]
     QUERY = {
-        "partitionId": {"projectId": GCP_PROJECT_ID, "namespaceId": ""},
+        "partitionId": {"projectId": GCP_PROJECT_ID, "namespaceId": "query"},
         "readOptions": {"transaction": begin_transaction_query.output},
         "query": {},
     }
