@@ -37,6 +37,7 @@ from google.cloud import storage
 from google.cloud.exceptions import GoogleCloudError
 
 from airflow.exceptions import AirflowException
+from airflow.providers.google.cloud.utils.helpers import normalize_directory_path
 from airflow.providers.google.common.hooks.base_google import GoogleBaseHook
 from airflow.utils import timezone
 from airflow.version import version
@@ -1065,8 +1066,8 @@ class GCSHook(GoogleBaseHook):
         source_bucket_obj = client.bucket(source_bucket)
         destination_bucket_obj = client.bucket(destination_bucket)
         # Normalize parameters when they are passed
-        source_object = self._normalize_directory_path(source_object)
-        destination_object = self._normalize_directory_path(destination_object)
+        source_object = normalize_directory_path(source_object)
+        destination_object = normalize_directory_path(destination_object)
         # Calculate the number of characters that remove from the name, because they contain information
         # about the parent's path
         source_object_prefix_len = len(source_object) if source_object else 0
@@ -1137,9 +1138,6 @@ class GCSHook(GoogleBaseHook):
             else blob.name[source_object_prefix_len:]
         )
 
-    def _normalize_directory_path(self, source_object: Optional[str]) -> Optional[str]:
-        return source_object + "/" if source_object and not source_object.endswith("/") else source_object
-
     @staticmethod
     def _prepare_sync_plan(
         source_bucket: storage.Bucket,
