@@ -39,6 +39,7 @@ from airflow.providers.google.cloud.hooks.cloud_storage_transfer_service import
     MONTH,
     NAME,
     OBJECT_CONDITIONS,
+    PATH,
     PROJECT_ID,
     SCHEDULE,
     SCHEDULE_END_DATE,
@@ -53,6 +54,7 @@ from airflow.providers.google.cloud.hooks.cloud_storage_transfer_service import
     CloudDataTransferServiceHook,
     GcpTransferJobsStatus,
 )
+from airflow.providers.google.cloud.utils.helpers import normalize_directory_path
 
 
 class TransferJobPreprocessor:
@@ -763,6 +765,10 @@ class CloudDataTransferServiceS3ToGCSOperator(BaseOperator):
     :param gcs_bucket: The destination Google Cloud Storage bucket
         where you want to store the files. (templated)
     :type gcs_bucket: str
+    :param s3_path: Optional root path where the source objects are. (templated)
+    :type s3_path: str
+    :param gcs_path: Optional root path for transferred objects. (templated)
+    :type gcs_path: str
     :param project_id: Optional ID of the Google Cloud Console project that
         owns the job
     :type project_id: str
@@ -815,6 +821,8 @@ class CloudDataTransferServiceS3ToGCSOperator(BaseOperator):
         'gcp_conn_id',
         's3_bucket',
         'gcs_bucket',
+        's3_path',
+        'gcs_path',
         'description',
         'object_conditions',
         'google_impersonation_chain',
@@ -826,6 +834,8 @@ class CloudDataTransferServiceS3ToGCSOperator(BaseOperator):
         *,
         s3_bucket: str,
         gcs_bucket: str,
+        s3_path: Optional[str] = None,
+        gcs_path: Optional[str] = None,
         project_id: Optional[str] = None,
         aws_conn_id: str = 'aws_default',
         gcp_conn_id: str = 'google_cloud_default',
@@ -844,6 +854,8 @@ class CloudDataTransferServiceS3ToGCSOperator(BaseOperator):
         super().__init__(**kwargs)
         self.s3_bucket = s3_bucket
         self.gcs_bucket = gcs_bucket
+        self.s3_path = s3_path
+        self.gcs_path = gcs_path
         self.project_id = project_id
         self.aws_conn_id = aws_conn_id
         self.gcp_conn_id = gcp_conn_id
@@ -884,8 +896,14 @@ class CloudDataTransferServiceS3ToGCSOperator(BaseOperator):
             DESCRIPTION: self.description,
             STATUS: GcpTransferJobsStatus.ENABLED,
             TRANSFER_SPEC: {
-                AWS_S3_DATA_SOURCE: {BUCKET_NAME: self.s3_bucket},
-                GCS_DATA_SINK: {BUCKET_NAME: self.gcs_bucket},
+                AWS_S3_DATA_SOURCE: {
+                    BUCKET_NAME: self.s3_bucket,
+                    PATH: normalize_directory_path(self.s3_path),
+                },
+                GCS_DATA_SINK: {
+                    BUCKET_NAME: self.gcs_bucket,
+                    PATH: normalize_directory_path(self.gcs_path),
+                },
             },
         }
 
@@ -935,6 +953,10 @@ class CloudDataTransferServiceGCSToGCSOperator(BaseOperator):
     :param destination_bucket: The destination Google Cloud Storage bucket
         where the object should be. (templated)
     :type destination_bucket: str
+    :param source_path: Optional root path where the source objects are. (templated)
+    :type source_path: str
+    :param destination_path: Optional root path for transferred objects. (templated)
+    :type destination_path: str
     :param project_id: The ID of the Google Cloud Console project that
         owns the job
     :type project_id: str
@@ -985,6 +1007,8 @@ class CloudDataTransferServiceGCSToGCSOperator(BaseOperator):
         'gcp_conn_id',
         'source_bucket',
         'destination_bucket',
+        'source_path',
+        'destination_path',
         'description',
         'object_conditions',
         'google_impersonation_chain',
@@ -996,6 +1020,8 @@ class CloudDataTransferServiceGCSToGCSOperator(BaseOperator):
         *,
         source_bucket: str,
         destination_bucket: str,
+        source_path: Optional[str] = None,
+        destination_path: Optional[str] = None,
         project_id: Optional[str] = None,
         gcp_conn_id: str = 'google_cloud_default',
         delegate_to: Optional[str] = None,
@@ -1013,6 +1039,8 @@ class CloudDataTransferServiceGCSToGCSOperator(BaseOperator):
         super().__init__(**kwargs)
         self.source_bucket = source_bucket
         self.destination_bucket = destination_bucket
+        self.source_path = source_path
+        self.destination_path = destination_path
         self.project_id = project_id
         self.gcp_conn_id = gcp_conn_id
         self.delegate_to = delegate_to
@@ -1053,8 +1081,14 @@ class CloudDataTransferServiceGCSToGCSOperator(BaseOperator):
             DESCRIPTION: self.description,
             STATUS: GcpTransferJobsStatus.ENABLED,
             TRANSFER_SPEC: {
-                GCS_DATA_SOURCE: {BUCKET_NAME: self.source_bucket},
-                GCS_DATA_SINK: {BUCKET_NAME: self.destination_bucket},
+                GCS_DATA_SOURCE: {
+                    BUCKET_NAME: self.source_bucket,
+                    PATH: normalize_directory_path(self.source_path),
+                },
+                GCS_DATA_SINK: {
+                    BUCKET_NAME: self.destination_bucket,
+                    PATH: normalize_directory_path(self.destination_path),
+                },
             },
         }
 
