@@ -23,7 +23,7 @@ from google.api_core.retry import exponential_sleep_generator
 from googleapiclient.errors import HttpError
 
 from airflow.models import BaseOperator
-from airflow.providers.google.cloud.hooks.datafusion import DataFusionHook
+from airflow.providers.google.cloud.hooks.datafusion import SUCCESS_STATES, DataFusionHook, PipelineStates
 
 
 class CloudDataFusionRestartInstanceOperator(BaseOperator):
@@ -780,6 +780,10 @@ class CloudDataFusionStartPipelineOperator(BaseOperator):
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
     :type impersonation_chain: Union[str, Sequence[str]]
+    :param asynchronous: Flag to return after submitting the pipeline Id to the Data Fusion API.
+        This is useful for submitting long running pipelines and
+        waiting on them asynchronously using the CloudDataFusionPipelineStateSensor
+    :type asynchronous: bool
     """
 
     template_fields = (
@@ -798,19 +802,18 @@ class CloudDataFusionStartPipelineOperator(BaseOperator):
         runtime_args: Optional[Dict[str, Any]] = None,
         success_states: Optional[List[str]] = None,
         namespace: str = "default",
-        pipeline_timeout: int = 10 * 60,
+        pipeline_timeout: int = 5 * 60,
         project_id: Optional[str] = None,
         api_version: str = "v1beta1",
         gcp_conn_id: str = "google_cloud_default",
         delegate_to: Optional[str] = None,
         impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        asynchronous=False,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
         self.pipeline_name = pipeline_name
-        self.success_states = success_states
         self.runtime_args = runtime_args
-        self.pipeline_timeout = pipeline_timeout
         self.namespace = namespace
         self.instance_name = instance_name
         self.location = location
@@ -819,8 +822,15 @@ class CloudDataFusionStartPipelineOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
+        self.asynchronous = asynchronous
+        self.pipeline_timeout = pipeline_timeout
 
-    def execute(self, context: dict) -> None:
+        if success_states:
+            self.success_states = success_states
+        else:
+            self.success_states = SUCCESS_STATES + [PipelineStates.RUNNING]
+
+    def execute(self, context: dict) -> str:
         hook = DataFusionHook(
             gcp_conn_id=self.gcp_conn_id,
             delegate_to=self.delegate_to,
@@ -840,9 +850,10 @@ class CloudDataFusionStartPipelineOperator(BaseOperator):
             namespace=self.namespace,
             runtime_args=self.runtime_args,
         )
+        self.log.info("Pipeline %s submitted successfully.", pipeline_id)
 
-        self.log.info("Pipeline started")
-        if self.success_states:
+        if not self.asynchronous:
+            self.log.info("Waiting when pipeline %s will be in one of the success states", pipeline_id)
             hook.wait_for_pipeline_state(
                 success_states=self.success_states,
                 pipeline_id=pipeline_id,
@@ -851,6 +862,8 @@ class CloudDataFusionStartPipelineOperator(BaseOperator):
                 instance_url=api_url,
                 timeout=self.pipeline_timeout,
             )
+            self.log.info("Job %s discover success state.", pipeline_id)
+        return pipeline_id
 
 
 class CloudDataFusionStopPipelineOperator(BaseOperator):
